@@ -1,6 +1,7 @@
 OC.L10N.register(
     "bookmarks",
     {
+    "Link copied to clipboard" : "Kiungo kimenakiliwa kwenye ubao wakunakilia",
     "Details" : "Maelezo ya kina",
     "Rename" : "Ipe jina jipya",
     "Copy link" : "Nakili kiungio",
@@ -15,6 +16,7 @@ OC.L10N.register(
     "Empty trash bin" : "Weka tupu chombo cha takataka",
     "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
     "Shared by {user}" : "Imeshirikishwa na{user}",
+    "Rename folder" : "Rename folder",
     "Submit" : "Wasilisha",
     "Cancel" : "Cancel",
     "Recent" : "Hivi karibuni",
@@ -25,12 +27,18 @@ OC.L10N.register(
     "Need help?" : "Unahitaji masaada?",
     "Title" : "Kichwa cha habari",
     "Link" : "Kiungio",
+    "Root folder" : "Root folder",
     "Tags" : "Maoni",
     "Notes" : "Madokezo",
+    "Link copied" : "Kiungo kimenakiliwa",
     "Owner" : "Mmiliki",
     "Sharing" : "inashirikisha",
+    "Select a user or group" : "Select a user or group",
     "Share link" : "Shirikisha kiungo",
+    "Create public link" : "Tengeneza kiungo cha umma",
+    "Allow editing" : "Ruhusu kuhariri",
     "Failed to save settings" : "Failed to save settings",
+    "Failed to load settings" : "Failed to load settings",
     "Privacy" : "Faragha",
     "Folder" : "Kisanduku",
     "Save" : "Hifadhi",
